@@ -1,4 +1,6 @@
 #![deny(clippy::all)]
+#![deny(clippy::all)]
+#![deny(unused)]
 #![allow(clippy::result_unit_err)]
 
 use std::{
@@ -31,8 +33,9 @@ use swc_ecma_transforms_base::{
     fixer,
     helpers::{inject_helpers, HELPERS},
     hygiene,
+    pass::noop,
 };
-use swc_ecma_utils::{quote_ident, quote_str, DropSpan, ExprFactory};
+use swc_ecma_utils::{quote_ident, quote_str, ExprFactory};
 use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, FoldWith, VisitMut, VisitMutWith};
 use tempfile::tempdir_in;
 use testing::{assert_eq, find_executable, NormalizedOutput};
@@ -40,6 +43,12 @@ use testing::{assert_eq, find_executable, NormalizedOutput};
 pub struct Tester<'a> {
     pub cm: Lrc<SourceMap>,
     pub handler: &'a Handler,
+    /// This will be changed to [SingleThreadedComments] once `cargo-mono`
+    /// supports correct bumping logic, or we need to make a breaking change in
+    /// a upstream crate of this crate.
+    ///
+    /// Although type is `Rc<SingleThreadedComments>`, it's fine to clone
+    /// `SingleThreadedComments` without `Rc`.
     pub comments: Rc<SingleThreadedComments>,
 }
 
@@ -164,9 +173,6 @@ impl<'a> Tester<'a> {
 
         let module = module
             .fold_with(&mut tr)
-            .fold_with(&mut as_folder(DropSpan {
-                preserve_ctxt: true,
-            }))
             .fold_with(&mut as_folder(Normalizer));
 
         Ok(module)
@@ -289,6 +295,9 @@ pub fn test_transform<F, P>(
         }
 
         let actual = actual
+            .fold_with(&mut as_folder(::swc_ecma_utils::DropSpan {
+                preserve_ctxt: true,
+            }))
             .fold_with(&mut hygiene::hygiene())
             .fold_with(&mut fixer::fixer(Some(&tester.comments)));
 
@@ -682,14 +691,7 @@ fn test_fixture_inner<P>(
     let expected = expected.unwrap_or_default();
 
     let expected_src = Tester::run(|tester| {
-        let expected_module = tester.apply_transform(
-            as_folder(::swc_ecma_utils::DropSpan {
-                preserve_ctxt: true,
-            }),
-            "expected.js",
-            syntax,
-            &expected,
-        )?;
+        let expected_module = tester.apply_transform(noop(), "expected.js", syntax, &expected)?;
 
         let expected_src = tester.print(&expected_module, &tester.comments.clone());
 
@@ -730,10 +732,7 @@ fn test_fixture_inner<P>(
 
         let actual = actual
             .fold_with(&mut crate::hygiene::hygiene())
-            .fold_with(&mut crate::fixer::fixer(Some(&tester.comments)))
-            .fold_with(&mut as_folder(DropSpan {
-                preserve_ctxt: false,
-            }));
+            .fold_with(&mut crate::fixer::fixer(Some(&tester.comments)));
 
         let actual_src = tester.print(&actual, &tester.comments.clone());
 
